==> aptechka-0.41.6.tgz: package/lib/device/index.js <==
var P = (t) => {
  throw TypeError(t);
};
var W = (t, s, n) => s.has(t) || P("Cannot " + n);
var e = (t, s, n) => (W(t, s, "read from private field"), n ? n.call(t) : s.get(t)), o = (t, s, n) => s.has(t) ? P("Cannot add the same private member more than once") : s instanceof WeakSet ? s.add(t) : s.set(t, n), i = (t, s, n, b) => (W(t, s, "write to private field"), b ? b.call(t, n) : s.set(t, n), n);
import { RESIZE_ORDER as A } from "../order/index.js";
import { windowResizer as k } from "../window-resizer/vanilla/index.js";
import { i as C } from "../browser-0zX67oeU.js";
import { S as T } from "../Store-Cm3LPXlx.js";
var h, w, f, m, a, d, l, c;
class D {
  constructor() {
    o(this, h);
    o(this, w);
    o(this, f);
    o(this, m);
    o(this, a);
    o(this, d);
    o(this, l);
    o(this, c);
    var s, n;
    if (i(this, h, "unknown"), i(this, w, "unknown"), i(this, f, 0), i(this, m, !1), i(this, a, !1), i(this, d, !1), i(this, l, !1), i(this, c, !1), this.resize = () => {
      i(this, m, /Mobi|Android/i.test(navigator.userAgent)), i(this, a, "ontouchstart" in window || navigator.maxTouchPoints > 0), setTimeout(() => {
        i(this, a, "ontouchstart" in window || navigator.maxTouchPoints > 0);
      }, 0);
    }, C) {
      this.resize(), k.subscribe(this.resize, A.DEVICE);
      {
        const p = document.createElement("canvas"), E = p.getContext("webgl") || p.getContext("experimental-webgl");
        i(this, d, E && E instanceof WebGLRenderingContext || !1);
      }
      {
        const p = document.createElement("canvas");
        p.getContext("2d") && i(this, l, p.toDataURL("image/webp").indexOf("data:image/webp") == 0);
      }
      const b = window.navigator.userAgent, v = ((n = (s = window.navigator) == null ? void 0 : s.userAgentData) == null ? void 0 : n.platform) || window.navigator.platform, S = [
        "Macintosh",
        "MacIntel",
        "MacPPC",
        "Mac68K",
        "macOS"
      ], z = ["Win32", "Win64", "Windows", "WinCE"], O = ["iPhone", "iPad", "iPod"];
      S.includes(v) ? (i(this, h, "macOS"), i(this, c, !0)) : O.includes(v) ? (i(this, h, "iOS"), i(this, c, !0)) : z.includes(v) ? i(this, h, "Windows") : /Android/.test(b) ? i(this, h, "Android") : /Linux/.test(v) ? i(this, h, "Linux") : i(this, h, "unknown");
    }
  }
  get OS() {
    return e(this, h);
  }
  get gpu() {
    return e(this, w);
  }
  get gpuTier() {
    return e(this, f);
  }
  get isMobile() {
    return e(this, m);
  }
  get isTouch() {
    return e(this, a);
  }
  get isWebgl() {
    return e(this, d);
  }
  get isWebp() {
    return e(this, l);
  }
  get isApple() {
    return e(this, c);
  }
}
h = new WeakMap(), w = new WeakMap(), f = new WeakMap(), m = new WeakMap(), a = new WeakMap(), d = new WeakMap(), l = new WeakMap(), c = new WeakMap();
const U = new D();
var I = /* @__PURE__ */ ((t) => (t.mobile = "600px", t.tablet = "1024px", t.notebook = "1280px", t.desktop = "1281px", t))(I || {}), L = /* @__PURE__ */ ((t) => (t["<=mobile"] = "(max-width: 600px)", t[">=mobile"] = "(min-width: 601px)", t["<=tablet"] = "(max-width: 1024px)", t[">=tablet"] = "(min-width: 1025px)", t["<=notebook"] = "(max-width: 1280px)", t[">=notebook"] = "(min-width: 1281px)", t["<=desktop"] = "(max-width: 1280px)", t[">=desktop"] = "(min-width: 1281px)", t))(L || {}), u, g, x, r;
class M {
  constructor() {
    o(this, u);
    o(this, g);
    o(this, x);
    o(this, r);
    i(this, u, 0), i(this, g, 0), i(this, x, 0), i(this, r, new T(void 0)), this.resize = () => {
      i(this, u, document.documentElement.clientWidth), i(this, g, innerHeight), i(this, x, devicePixelRatio), matchMedia(
        "(max-width: 600px)"
        /* <=mobile */
      ).matches ? e(this, r).current = "mobile" : matchMedia(
        "(max-width: 1024px)"
        /* <=tablet */
      ).matches ? e(this, r).current = "tablet" : matchMedia(
        "(max-width: 1280px)"
        /* <=notebook */
      ).matches ? e(this, r).current = "notebook" : matchMedia(
        "(min-width: 1281px)"
        /* >=desktop */
      ).matches && (e(this, r).current = "desktop");
    }, C && (this.resize(), k.subscribe(this.resize, A.DEVICE));
  }
  get width() {
    return e(this, u);
  }
  get height() {
    return e(this, g);
  }
  get type() {
    return e(this, r);
  }
  get pixelRatio() {
    return e(this, x);
  }
}
u = new WeakMap(), g = new WeakMap(), x = new WeakMap(), r = new WeakMap();
const Z = new M();
export {
  I as ViewportBreakpoints,
  L as ViewportMediaRules,
  U as device,
  Z as viewport
};

==> aptechka-0.42.1.tgz: package/lib/device/index.js <==
var P = (t) => {
  throw TypeError(t);
};
var W = (t, s, n) => s.has(t) || P("Cannot " + n);
var e = (t, s, n) => (W(t, s, "read from private field"), n ? n.call(t) : s.get(t)), o = (t, s, n) => s.has(t) ? P("Cannot add the same private member more than once") : s instanceof WeakSet ? s.add(t) : s.set(t, n), i = (t, s, n, b) => (W(t, s, "write to private field"), b ? b.call(t, n) : s.set(t, n), n);
import { RESIZE_ORDER as A } from "../order/index.js";
import { windowResizer as k } from "../window-resizer/index.js";
import { i as C } from "../browser-0zX67oeU.js";
import { S as T } from "../Store-Cm3LPXlx.js";
var h, w, f, m, a, d, l, c;
class D {
  constructor() {
    o(this, h);
    o(this, w);
    o(this, f);
    o(this, m);
    o(this, a);
    o(this, d);
    o(this, l);
    o(this, c);
    var s, n;
    if (i(this, h, "unknown"), i(this, w, "unknown"), i(this, f, 0), i(this, m, !1), i(this, a, !1), i(this, d, !1), i(this, l, !1), i(this, c, !1), this.resize = () => {
      i(this, m, /Mobi|Android/i.test(navigator.userAgent)), i(this, a, "ontouchstart" in window || navigator.maxTouchPoints > 0), setTimeout(() => {
        i(this, a, "ontouchstart" in window || navigator.maxTouchPoints > 0);
      }, 0);
    }, C) {
      this.resize(), k.subscribe(this.resize, A.DEVICE);
      {
        const p = document.createElement("canvas"), E = p.getContext("webgl") || p.getContext("experimental-webgl");
        i(this, d, E && E instanceof WebGLRenderingContext || !1);
      }
      {
        const p = document.createElement("canvas");
        p.getContext("2d") && i(this, l, p.toDataURL("image/webp").indexOf("data:image/webp") == 0);
      }
      const b = window.navigator.userAgent, v = ((n = (s = window.navigator) == null ? void 0 : s.userAgentData) == null ? void 0 : n.platform) || window.navigator.platform, S = [
        "Macintosh",
        "MacIntel",
        "MacPPC",
        "Mac68K",
        "macOS"
      ], z = ["Win32", "Win64", "Windows", "WinCE"], O = ["iPhone", "iPad", "iPod"];
      S.includes(v) ? (i(this, h, "macOS"), i(this, c, !0)) : O.includes(v) ? (i(this, h, "iOS"), i(this, c, !0)) : z.includes(v) ? i(this, h, "Windows") : /Android/.test(b) ? i(this, h, "Android") : /Linux/.test(v) ? i(this, h, "Linux") : i(this, h, "unknown");
    }
  }
  get OS() {
    return e(this, h);
  }
  get gpu() {
    return e(this, w);
  }
  get gpuTier() {
    return e(this, f);
  }
  get isMobile() {
    return e(this, m);
  }
  get isTouch() {
    return e(this, a);
  }
  get isWebgl() {
    return e(this, d);
  }
  get isWebp() {
    return e(this, l);
  }
  get isApple() {
    return e(this, c);
  }
}
h = new WeakMap(), w = new WeakMap(), f = new WeakMap(), m = new WeakMap(), a = new WeakMap(), d = new WeakMap(), l = new WeakMap(), c = new WeakMap();
const U = new D();
var I = /* @__PURE__ */ ((t) => (t.mobile = "600px", t.tablet = "1024px", t.notebook = "1280px", t.desktop = "1281px", t))(I || {}), L = /* @__PURE__ */ ((t) => (t["<=mobile"] = "(max-width: 600px)", t[">=mobile"] = "(min-width: 601px)", t["<=tablet"] = "(max-width: 1024px)", t[">=tablet"] = "(min-width: 1025px)", t["<=notebook"] = "(max-width: 1280px)", t[">=notebook"] = "(min-width: 1281px)", t["<=desktop"] = "(max-width: 1280px)", t[">=desktop"] = "(min-width: 1281px)", t))(L || {}), u, g, x, r;
class M {
  constructor() {
    o(this, u);
    o(this, g);
    o(this, x);
    o(this, r);
    i(this, u, 0), i(this, g, 0), i(this, x, 0), i(this, r, new T(void 0)), this.resize = () => {
      i(this, u, document.documentElement.clientWidth), i(this, g, innerHeight), i(this, x, devicePixelRatio), matchMedia(
        "(max-width: 600px)"
        /* <=mobile */
      ).matches ? e(this, r).current = "mobile" : matchMedia(
        "(max-width: 1024px)"
        /* <=tablet */
      ).matches ? e(this, r).current = "tablet" : matchMedia(
        "(max-width: 1280px)"
        /* <=notebook */
      ).matches ? e(this, r).current = "notebook" : matchMedia(
        "(min-width: 1281px)"
        /* >=desktop */
      ).matches && (e(this, r).current = "desktop");
    }, C && (this.resize(), k.subscribe(this.resize, A.DEVICE));
  }
  get width() {
    return e(this, u);
  }
  get height() {
    return e(this, g);
  }
  get type() {
    return e(this, r);
  }
  get pixelRatio() {
    return e(this, x);
  }
}
u = new WeakMap(), g = new WeakMap(), x = new WeakMap(), r = new WeakMap();
const Z = new M();
export {
  I as ViewportBreakpoints,
  L as ViewportMediaRules,
  U as device,
  Z as viewport
};
